ConfigurationError

Enum ConfigurationError 

#[non_exhaustive]
pub enum ConfigurationError { ReadConfigurationFile { path: PathBuf, source: Error, }, ParseConfigurationFile { path: PathBuf, source: Error, }, InvalidConfigurationDocument { path: PathBuf, reason: String, }, DuplicateConfigurationKey { path: PathBuf, key: String, }, UnknownWorkloadConfiguration { component: String, workload: String, }, CombinationCountOverflow { axis: String, }, CombinationOrdinalOutOfBounds { ordinal: u64, combination_count: u64, }, UnknownConfigurationValue { ordinal: u64, key: String, }, DecodeConfigurationValue { ordinal: u64, key: String, source: Error, }, UnknownProjectPath { key: String, }, }
A failure encountered while loading study settings, paths, or parameters.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ReadConfigurationFile

A configuration source could not be read from the filesystem.

Fields

path: PathBuf

Source path that could not be read.

source: Error

Underlying filesystem failure.



ParseConfigurationFile

A source file was not valid JSON.

Fields

path: PathBuf

Source path containing invalid JSON.

source: Error

Underlying JSON syntax failure.



InvalidConfigurationDocument

Valid JSON did not conform to the configuration grammar.

Fields

path: PathBuf

Rejected source path.

reason: String

Contextual grammar violation.



DuplicateConfigurationKey

A JSON object repeated a key that would otherwise be overwritten.

Fields

path: PathBuf

Source path containing the duplicate.

key: String

Repeated JSON object key.



UnknownWorkloadConfiguration

A requested component-qualified workload is not declared.

Fields

component: String

Requested component key.

workload: String

Requested workload key.



CombinationCountOverflow

The Cartesian product cannot be represented by a u64 ordinal.

Fields

axis: String

Sweep axis or phase composition that caused the overflow.



CombinationOrdinalOutOfBounds

A requested flattened ordinal is outside its workload configuration.

Fields

ordinal: u64

Requested zero-based ordinal.

combination_count: u64

Number of valid combinations in the workload.



UnknownConfigurationValue

A resolved configuration does not contain a requested JSON Pointer.

Fields

ordinal: u64

Flattened combination ordinal being inspected.

key: String

Missing canonical JSON Pointer.



DecodeConfigurationValue

A present configuration value could not be decoded as the requested type.

Fields

ordinal: u64

Flattened combination ordinal being decoded.

key: String

Canonical JSON Pointer of the value.

source: Error

Underlying Serde conversion failure.



UnknownProjectPath

The named project-path table does not contain a requested key.

Fields

key: String

Missing project-path key.