pub struct ConfigurationSpace { /* private fields */ }Implementations
Sourceimpl ConfigurationSpace
impl ConfigurationSpace
Sourcepub fn load(
configuration_directory: impl Into<PathBuf>,
) -> Result<Self, ConfigurationError>
pub fn load( configuration_directory: impl Into<PathBuf>, ) -> Result<Self, ConfigurationError>
Loads and validates fixed.json and sweep.json from directory.
Sourcepub fn directory(&self) -> &Path
pub fn directory(&self) -> &Path
Returns the configuration directory exactly as supplied during loading.
pub fn fixed_source_json(&self) -> &[u8] ⓘ
pub fn sweep_source_json(&self) -> &[u8] ⓘ
Sourcepub fn fixed_value_count(&self) -> usize
pub fn fixed_value_count(&self) -> usize
Returns the number of fixed terminal values.
Sourcepub fn sweep_dimension_count(&self) -> usize
pub fn sweep_dimension_count(&self) -> usize
Returns the number of independently selected sweep paths.
pub fn combination_count(&self) -> u64
Sourcepub fn contains(&self, key: &str) -> bool
pub fn contains(&self, key: &str) -> bool
Reports whether a fixed or swept value exists at or beneath key.
pub fn fixed_keys(&self) -> impl ExactSizeIterator<Item = &str>
pub fn sweep_keys(&self) -> impl ExactSizeIterator<Item = &str>
pub fn combination( &self, ordinal: u64, ) -> Result<ResolvedConfiguration, ConfigurationError>
pub fn combinations(&self) -> ConfigurationIter ⓘ