pub struct ReplicateSettings { /* private fields */ }Expand description
Validated policy for executing one or more isolated study replicates.
Implementations
Sourceimpl ReplicateSettings
impl ReplicateSettings
Sourcepub const fn replicates(self) -> u64
pub const fn replicates(self) -> u64
Returns the positive number of replicate subprocesses.
Sourcepub const fn scheduling(self) -> ReplicateScheduling
pub const fn scheduling(self) -> ReplicateScheduling
Returns whether replicate subprocesses are scheduled sequentially or in parallel.
Sourcepub const fn failure_policy(self) -> ReplicateFailurePolicy
pub const fn failure_policy(self) -> ReplicateFailurePolicy
Returns the controller response to a failed replicate subprocess.