#[non_exhaustive]pub enum ReplicateExecutionError {
CurrentExecutable(Error),
InvalidWorkerIndex {
variable: &'static str,
value: String,
},
WorkerIndexOutOfRange {
index: u64,
replicates: u64,
},
PrepareOutput {
index: u64,
source: ExecutionScopeError,
},
RunProcess {
index: u64,
source: Error,
},
ReplicatesFailed {
indices: Vec<u64>,
},
}Expand description
Failure while dispatching or entering a replicate subprocess.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CurrentExecutable(Error)
The operating system could not identify the running executable.
InvalidWorkerIndex
The reserved worker environment variable was not a valid index.
Fields
WorkerIndexOutOfRange
A worker index does not belong to the currently loaded settings.
PrepareOutput
A replicate output scope could not be created or reopened.
Fields

source: ExecutionScopeErrorFilesystem scope failure.
RunProcess
A replicate process could not be started or observed.
Fields
ReplicatesFailed
One or more replicate subprocesses returned unsuccessful statuses.