#[non_exhaustive]pub enum PhaseFailurePolicy {
FailFast,
FinishActive,
}Expand description
Scheduling behavior after the first workload failure in a phase.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FailFast
Stop new work and cooperatively cancel active workloads.
FinishActive
Stop new work but allow already active workloads to finish.
Implementations