pub struct CompletedRecording { /* private fields */ }Expand description
Durable result of a successfully completed recording lifecycle.
The active writer has been consumed and all metadata and chunks are durable before this handle is created. It cannot append data.
Implementations
Sourceimpl CompletedRecording
impl CompletedRecording
Sourcepub fn timing(&self) -> &RecordingTiming
pub fn timing(&self) -> &RecordingTiming
Returns automatically captured operational timing.
Sourcepub fn terminal_metadata(&self) -> &Map<String, Value>
pub fn terminal_metadata(&self) -> &Map<String, Value>
Returns caller-supplied terminal metadata committed with completion.
Sourcepub fn stream_summaries(&self) -> &[CompletedStreamSummary]
pub fn stream_summaries(&self) -> &[CompletedStreamSummary]
Returns stream summaries in declaration order.
Sourcepub fn stream_summary(&self, name: &str) -> Option<&CompletedStreamSummary>
pub fn stream_summary(&self, name: &str) -> Option<&CompletedStreamSummary>
Looks up one completed stream summary by exact name.