#[non_exhaustive]pub enum ConfigurationError {
ReadConfigurationFile {
path: PathBuf,
source: Error,
},
ParseConfigurationFile {
path: PathBuf,
source: Error,
},
InvalidConfigurationDocument {
path: PathBuf,
reason: String,
},
DuplicateConfigurationKey {
path: PathBuf,
key: String,
},
UnknownWorkloadConfiguration {
component: String,
workload: String,
},
CombinationCountOverflow {
axis: String,
},
CombinationOrdinalOutOfBounds {
ordinal: u64,
combination_count: u64,
},
UnknownConfigurationValue {
ordinal: u64,
key: String,
},
DecodeConfigurationValue {
ordinal: u64,
key: String,
source: Error,
},
UnknownProjectPath {
key: String,
},
}Expand description
A failure encountered while loading study settings, paths, or parameters.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ReadConfigurationFile
A configuration source could not be read from the filesystem.
Fields
ParseConfigurationFile
A source file was not valid JSON.
Fields
InvalidConfigurationDocument
Valid JSON did not conform to the configuration grammar.
DuplicateConfigurationKey
A JSON object repeated a key that would otherwise be overwritten.
UnknownWorkloadConfiguration
A requested component-qualified workload is not declared.
CombinationCountOverflow
The Cartesian product cannot be represented by a u64 ordinal.
CombinationOrdinalOutOfBounds
A requested flattened ordinal is outside its workload configuration.
Fields
UnknownConfigurationValue
A resolved configuration does not contain a requested JSON Pointer.
Fields
DecodeConfigurationValue
A present configuration value could not be decoded as the requested type.
Fields
UnknownProjectPath
The named project-path table does not contain a requested key.