pub struct ResolvedConfiguration { /* private fields */ }Implementations
Sourceimpl ResolvedConfiguration
impl ResolvedConfiguration
pub fn ordinal(&self) -> u64
Sourcepub fn value(&self, key: &str) -> Option<&Value>
pub fn value(&self, key: &str) -> Option<&Value>
Borrows an exact leaf or lazily reconstructed nested subtree.
pub fn require_value(&self, key: &str) -> Result<&Value, ConfigurationError>
pub fn decode_value<T>(&self, key: &str) -> Result<T, ConfigurationError>where
T: DeserializeOwned,
pub fn decode_values<Values, Keys>(
&self,
keys: Keys,
) -> Result<Values, ConfigurationError>where
Keys: ParameterKeyTuple<Values>,
pub fn contains(&self, key: &str) -> bool
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
Sourcepub fn keys(&self) -> impl Iterator<Item = &str>
pub fn keys(&self) -> impl Iterator<Item = &str>
Iterates canonical terminal parameter identifiers.
pub fn iter(&self) -> impl Iterator<Item = (&str, &Value)>
Sourcepub fn to_json(&self) -> Result<String, ConfigurationError>
pub fn to_json(&self) -> Result<String, ConfigurationError>
Serializes the complete rehydrated nested configuration document.
Sourcepub fn to_json_value(&self) -> Value
pub fn to_json_value(&self) -> Value
Clones the complete rehydrated nested configuration document.
The document is cached after its first reconstruction. This method is intended for durable provenance records that must own their JSON value.