#[non_exhaustive]pub enum ExecutionScopeError {
InvalidName {
name: String,
},
Timestamp {
source: Format,
},
Io {
operation: &'static str,
path: PathBuf,
source: Error,
},
IdentityExhausted {
root: PathBuf,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidName
A caller-supplied scope name was empty or not one safe path component.
Timestamp
The host UTC clock could not be formatted for the scope identity.
Io
A filesystem operation failed at a scope boundary.
Fields
IdentityExhausted
Generated identity attempts repeatedly collided with existing scopes.