CompletedRecording

Struct CompletedRecording 

pub struct CompletedRecording { /* private fields */ }
Durable result of a successfully completed recording lifecycle.

The active writer has been consumed and all metadata and chunks are durable before this handle is created. It cannot append data.

Implementations

Source

impl CompletedRecording

pub fn directory(&self) -> &Path

Returns the completed recording directory.

pub fn timing(&self) -> &RecordingTiming

Returns automatically captured operational timing.

pub fn terminal_metadata(&self) -> &Map<String, Value>

Returns caller-supplied terminal metadata committed with completion.

pub fn stream_summaries(&self) -> &[CompletedStreamSummary]

Returns stream summaries in declaration order.

pub fn stream_summary(&self, name: &str) -> Option<&CompletedStreamSummary>

Looks up one completed stream summary by exact name.